labeltools.color_measures_with_non_power_of_two_denominators_in_expr
====================================================================

.. autofunction:: abjad.tools.labeltools.color_measures_with_non_power_of_two_denominators_in_expr.color_measures_with_non_power_of_two_denominators_in_expr
